#' Calaculate floodplain habitat areas
#'
#' Calculate current and historical floodplain habitat areas
#'
#' @param df_fp output of hab_clean_floodplain()
#'
#' @export

hab_calc_fp_area <- function(df_fp){

  # take side channels back out, calculate pool/riffle area
  fp_sc <- df_fp %>%
    filter.(Habitat == 'Side_channel') %>%
    mutate.( # seasonal side channel habitat estimation
      pool_perc_scenario = pool_perc,
      SC_pool_summer = Area_ha * pool_perc_scenario,
      SC_riffle_summer = Area_ha * (1 - pool_perc_scenario),
      SC_pool_winter = SC_pool_summer * winter_pool_scalar_warm,
      SC_riffle_winter = SC_riffle_summer +
        (Area_ha * (1 - winter_pool_scalar_warm) * pool_perc)
      ) %>%
    select.(-c(Habitat, Area_ha)) %>%
    tidytable::pivot_longer.(# split habitat and life stages into separate cols
      cols = tidyr::starts_with("SC_"),
      names_to = c("Habitat", "life.stage"),
      names_pattern = "(SC_pool|SC_riffle)_(summer|winter)",
      values_to =  "Area_ha")

  # create seasons for ponds/marshes

  fp_pondmarsh <- df_fp %>% # make seasonal pond/marsh habitat
    filter.(!Habitat == 'Side_channel') %>%
    tidytable::expand_grid.(life.stage = c('summer', 'winter'))

  fp_all <- bind_rows.(fp_pondmarsh, fp_sc) %>%
    select.(
      Habitat,
      slope_class,
      noaaid,
      era,
      scenario,
      Area_ha,
      subbasin_num,
      pop,
      pool_perc,
      Period,
      rear,
      in_fp,
      bfw_conn,
      life.stage
    )

  fp_all %>%
    filter.(rear) %>%
    # current habs must be <5m from 1/2 BFW of stream.
    # historic habs must be in that distance or in floodplain
    mutate.(
      hist_area = (Period != "Curr")*(in_fp == 1|bfw_conn)*Area_ha,
      curr_area = (Period != "Hist")*(bfw_conn)*Area_ha) %>%
    # summarise total area by habitat and reach
    # good candidate for `collapse conversion`
    tidytable::summarise.(
      tidytable::across.(c(hist_area, curr_area), sum, na.rm = T),
      .by = c(noaaid, Habitat, life.stage, era, scenario, subbasin_num)) %>%
    left_join.(scenarios_df, by = c("noaaid", "scenario")) %>%
    mutate.(
      curr_area = tidytable::replace_na.(curr_area, 0), #another collapse cand.
      hist_area = tidytable::replace_na.(hist_area, 0),
      Area = apply_rest_action(
        curr_area,
        hist_area,
        rest_perc,
        fp_intensity_scalar
      )
    ) %>%
    select.(
      noaaid,
      Habitat,
      life.stage,
      era,
      scenario,
      subbasin_num,
      Area,
      names(scenarios_df))
}
