# Prep scenarios and restoration actions ---------------------------------------

# Subset flowline to spatial identifiers (noaaid) and confinement features only
flowline_id <- flowline_raw %>%
  transmute(
    noaaid,
    confined = fpw/BF_width < 4
  )

# Create combined action scenarios
# Combined scenarios apply actions at a particular percent effectiveness
combined_scenarios <-
  c(
    'Top4_25%',
    'Top4_50%',
    'Top4_75%',
    'Top5_25%',
    'Top5_50%',
    'Top5_75%',
    'All_25%',
    'All_50%',
    'All_75%',
    'All_100%'
  )

# Create diagnsotic scenarios---------------------------------------------------
# In a diagnostic scenario all reaches get the same treatment
diag_scenarios <- scenario_desc %>%
  filter(!grepl('dev_', scenario)) %>% #exclude dev scenarios
  pull(scenario)

# Create a set of actions that match the diagnostic scenarios
actions <- setdiff(diag_scenarios, c('Current', 'FP_wood_comb', 'Historical'))

# Duplicate flowline for each scenario
scenario_names <- c(diag_scenarios, 'dev_and_climate', combined_scenarios)

scenarios <- expand_grid(
  scenario = scenario_names,
  flowline_id
)

# Create a table of scenarios vs actions for each reach.
# This will be the 'scenarios' table for the diagnostic scenarios
diag_scenarios_df <- expand_grid(
  action = actions,
  scenarios) %>%
  mutate(
    yn = case_when(
      scenario == action ~ TRUE,
      scenario %in% c('Historical', 'All_25%', 'All_50%', 'All_75%', 'All_100%') ~ TRUE,
      scenario == 'FP_wood_comb' &
        action %in% c('Floodplain', 'Wood') ~ TRUE,
      str_detect(scenario, 'Top') &
        action %in% c('Beaver', 'Floodplain', 'Shade', 'Wood') ~ TRUE,
      str_detect(scenario, 'Top5') &
        action == 'Fine_sediment' ~ TRUE,
      TRUE ~ FALSE
    )
  ) %>%
  pivot_wider(scenario:confined, names_from = action, values_from = yn) %>%
  mutate(rest_perc = 1) %>%
  rename(Riparian = Shade,
         LW = Wood)


# Create "scenarios_df" which is exported for use in the model

scenarios_df <- diag_scenarios_df %>%
  mutate(
    beaver_intensity_scalar = case_when(
      str_detect(scenario, "75") ~ .75,
      str_detect(scenario, "50") ~ .5,
      str_detect(scenario, "25") ~ .25,
      !Beaver ~ 0,
      TRUE ~ 1
    ),
    temp_intensity_scalar = case_when(
      scenario %in% c("Shade", "Historical", "All_100%") ~ 1,
      str_detect(scenario, "75") ~ .75,
      str_detect(scenario, "50") ~ .5,
      str_detect(scenario, "25") ~ .25,
      TRUE ~ 0
    ),
    fp_intensity_scalar = case_when(
      str_detect(scenario, "75") ~ .75,
      str_detect(scenario, "50") ~ .5,
      str_detect(scenario, "25") ~ .25,
      !Floodplain ~ 0,
      TRUE ~ 1
    ),
    wood_intensity_scalar = case_when(
      str_detect(scenario, "75") ~ .75,
      str_detect(scenario, "50") ~ .5,
      str_detect(scenario, "25") ~ .25,
      !LW ~ 0,
      TRUE ~ 1
    ),
    ef_intensity_scalar = case_when( # not in top 4
      scenario %in% c("Fine_sediment", "Historical", "All_100%") ~ 1,
      scenario %in% c("Top5_25%", "All_25%") ~ .25,
      scenario %in% c("Top5_50%", "All_50%") ~ .5,
      scenario %in% c("Top5_75%", "All_75%") ~ .75,
      TRUE ~ 0
    ),
    lr_intensity_scalar = case_when( # not in top 5
      scenario %in% c("All_100%", "LR", "Historical") ~ 1,
      scenario == "All_75%" ~ .75,
      scenario == "All_50%" ~ .5,
      scenario == "All_25%" ~ .25,
      TRUE ~ 0
    ),
    delta_intensity_scalar = case_when( # not in top 5
      scenario %in% c("All_100%", "Delta", "Historical") ~ 1,
      scenario == "All_75%" ~ .75,
      scenario == "All_50%" ~ .5,
      scenario == "All_25%" ~ .25,
      TRUE ~ 0
    )
  )

# All scenarios run through harp model
scenarios_all <- c(diag_scenarios, combined_scenarios)
